@@ -3,7 +3,7 @@ use Moo;
 use MooX::HandlesVia;
 use Time::HiRes;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 =head1 NAME
 
@@ -76,7 +76,8 @@ sub query_end {
 
 =head1 AUTHOR
 
-osfameron <osfameron@cpan.org> 2014
+osfameron <osfameron@cpan.org> 2014-2017
+Alexander Hartmaier <abraxxa@cpan.org> 2017
 
 =cut
 
